@@ -17,8 +17,14 @@ def resize(file_, max_width=0, max_height=0, crop=0):
     max_height = 9999 if max_height is 0 else max_height
     
     size = (max_width, max_height)
-    
     image = Image.open(file_)
+    
+    if(str(file_.content_type) == 'image/png'):
+        image.load()
+        background = Image.new('RGB', image.size, (255, 255, 255))
+        background.paste(image, mask=image.split()[3])
+        image = background
+    
     temp = StringIO()
     
     if(crop is 1):
