@@ -23,7 +23,9 @@ class AjaxImageEditor(widgets.TextInput):
 
     class Media:
         js = (
-            'ajaximage/js/require.js',
+            'ajaximage/js/jquery.iframe-transport.js',
+            'ajaximage/js/jquery.ui.widget.js',
+            'ajaximage/js/jquery.fileupload.js',
             'ajaximage/js/ajaximage.js',
         )
         css = {
